==> XML-CompareML-0.2.12.tar.gz: XML-CompareML-0.2.12/lib/XML/CompareML/DocBook.pm <==
package XML::CompareML::DocBook;
$XML::CompareML::DocBook::VERSION = '0.2.12';
use strict;
use warnings;


use XML::LibXML::Common qw(:w3c);

use parent 'XML::CompareML::Base';

sub _print_header
{
    my $self = shift;
    my $o    = $self->{o};
    print { *{$o} } <<"EOF";
<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"
"/usr/share/sgml/docbook/xml-dtd-4.1.2/docbookx.dtd"[
]>
<article>

EOF
}

# Do Nothing
sub _start_rendering
{
}

# Do Nothing
sub _finish_rendering
{
}

sub _print_footer
{
    my $self = shift;
    print { *{ $self->{o} } } "</article>\n";
}

sub _render_section_start
{
    my $self = shift;
    my %args = (@_);

    my $depth        = $args{depth};
    my $id           = $args{id};
    my $title_string = $args{title_string};
    my $expl         = $args{expl};
    my $sub_sections = $args{sub_sections};

    if ($depth)
    {
        $self->_out("<section id=\"$id\">\n");
    }

    $self->_out("<title>$title_string</title>\n");

    if ( $depth == 0 )
    {
        if ( defined( $self->_timestamp() ) )
        {
            $self->_out( "<articleinfo><date>"
                    . $self->_timestamp()
                    . "</date></articleinfo>\n" );
        }
    }

    if ($expl)
    {
        $self->_out( "<para>\n"
                . $self->_xml_node_contents_to_string($expl)
                . "\n</para>\n" );
    }
}

sub _render_sys_table_start
{
    my ( $self, %args ) = @_;

    my $title_string = $args{title_string};

    $self->_out(<<"EOF");
<table frame=\"all\">
<title>Comparison - $title_string</title>
<tgroup cols=\"2\" align=\"left\" colsep=\"1\" rowsep=\"1\">
<colspec colname=\"system\" />
<colspec colname=\"description\" />
<thead>
<row>
<entry><emphasis>System</emphasis></entry>
<entry><emphasis>Description</emphasis></entry>
</row>
</thead>
<tbody>
EOF
}

sub _html_to_docbook
{
    my $parent_node = shift;
    my $not_first   = shift;
    my @child_nodes = $parent_node->childNodes();
    my $ret         = "";

    foreach my $node (@child_nodes)
    {
        if ( $node->nodeType() == ELEMENT_NODE() )
        {
            if ( $node->nodeName() eq "a" )
            {
                $ret .= "<ulink url=\"" . $node->getAttribute("href") . "\">";
            }
            else
            {
                my @attrs = $node->attributes();
                $ret .= "<"
                    . $node->nodeName() . " "
                    . join( " ",
                    map { "$_=\"" . $node->getAttribute($_) . "\"" } @attrs )
                    . ">";
            }
            $ret .= _html_to_docbook( $node, 1 );

            if ( $node->nodeName() eq "a" )
            {
                $ret .= "</ulink>";
            }
            else
            {
                $ret .= "</" . $node->nodeName() . ">";
            }
        }
        else
        {
            $ret .= $node->toString();
        }
    }

    # Remove leading and trailing space.
    if (1)
    {
        $ret =~ s!^\s+!!mg;
        $ret =~ s/\s+$//mg;
    }
    return $ret;
}

sub _render_s_elem
{
    my ( $self, $s_elem ) = @_;
    return _html_to_docbook($s_elem);
}

sub _render_sys_table_row
{
    my ( $self, %args ) = @_;

    $self->_out( "<row>\n<entry>"
            . $args{name}
            . "</entry>\n"
            . "<entry>\n"
            . $args{desc}
            . "\n</entry>\n</row>\n" );
}

sub _render_sys_table_end
{
    my $self = shift;
    $self->_out("</tbody>\n</tgroup>\n</table>\n");
}

sub _render_section_end
{
    my ( $self, %args ) = @_;

    my $depth = $args{depth};

    if ($depth)
    {
        $self->_out("</section>\n");
    }
}


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

XML::CompareML::DocBook - convert CompareML to DocBook

=head1 VERSION

version 0.2.12

=head1 SYNOPSIS

See L<XML::CompareXML>.

=head1 VERSION

version 0.2.12

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/>.

=head1 SEE ALSO

L<XML::CompareML>

=head1 COPYRIGHT AND LICENSE

Copyright 2004, Shlomi Fish. All rights reserved.

You can use, modify and distribute this module under the terms of the MIT X11
license. ( L<http://www.opensource.org/licenses/mit-license.php> ).

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/xml-compareml/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Perldoc

You can find documentation for this module with the perldoc command.

  perldoc XML::CompareML::DocBook

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/XML-CompareML>

=item *

Search CPAN

The default CPAN search engine, useful to view POD in HTML format.

L<http://search.cpan.org/dist/XML-CompareML>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-CompareML>

=item *

AnnoCPAN

The AnnoCPAN is a website that allows community annotations of Perl module documentation.

L<http://annocpan.org/dist/XML-CompareML>

=item *

CPAN Ratings

The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.

L<http://cpanratings.perl.org/d/XML-CompareML>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/XML-CompareML>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/X/XML-CompareML>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=XML-CompareML>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=XML::CompareML>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-xml-compareml at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-CompareML>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/xml-compareml>

  git clone git://github.com/shlomif/xml-compareml.git

=cut

==> XML-CompareML-0.2.13.tar.gz: XML-CompareML-0.2.13/lib/XML/CompareML/DocBook.pm <==
package XML::CompareML::DocBook;
$XML::CompareML::DocBook::VERSION = '0.2.13';
use strict;
use warnings;


use XML::LibXML::Common qw(:w3c);

use parent 'XML::CompareML::Base';

sub _print_header
{
    my $self = shift;
    my $o    = $self->{o};
    print { *{$o} } <<"EOF";
<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.1.2//EN"
"/usr/share/sgml/docbook/xml-dtd-4.1.2/docbookx.dtd"[
]>
<article>

EOF
}

# Do Nothing
sub _start_rendering
{
}

# Do Nothing
sub _finish_rendering
{
}

sub _print_footer
{
    my $self = shift;
    print { *{ $self->{o} } } "</article>\n";
}

sub _render_section_start
{
    my $self = shift;
    my %args = (@_);

    my $depth        = $args{depth};
    my $id           = $args{id};
    my $title_string = $args{title_string};
    my $expl         = $args{expl};
    my $sub_sections = $args{sub_sections};

    if ($depth)
    {
        $self->_out("<section id=\"$id\">\n");
    }

    $self->_out("<title>$title_string</title>\n");

    if ( $depth == 0 )
    {
        if ( defined( $self->_timestamp() ) )
        {
            $self->_out( "<articleinfo><date>"
                    . $self->_timestamp()
                    . "</date></articleinfo>\n" );
        }
    }

    if ($expl)
    {
        $self->_out( "<para>\n"
                . $self->_xml_node_contents_to_string($expl)
                . "\n</para>\n" );
    }
}

sub _render_sys_table_start
{
    my ( $self, %args ) = @_;

    my $title_string = $args{title_string};

    $self->_out(<<"EOF");
<table frame=\"all\">
<title>Comparison - $title_string</title>
<tgroup cols=\"2\" align=\"left\" colsep=\"1\" rowsep=\"1\">
<colspec colname=\"system\" />
<colspec colname=\"description\" />
<thead>
<row>
<entry><emphasis>System</emphasis></entry>
<entry><emphasis>Description</emphasis></entry>
</row>
</thead>
<tbody>
EOF
}

sub _html_to_docbook
{
    my $parent_node = shift;
    my $not_first   = shift;
    my @child_nodes = $parent_node->childNodes();
    my $ret         = "";

    foreach my $node (@child_nodes)
    {
        if ( $node->nodeType() == ELEMENT_NODE() )
        {
            if ( $node->nodeName() eq "a" )
            {
                $ret .= "<ulink url=\"" . $node->getAttribute("href") . "\">";
            }
            else
            {
                my @attrs = $node->attributes();
                $ret .= "<"
                    . $node->nodeName() . " "
                    . join( " ",
                    map { "$_=\"" . $node->getAttribute($_) . "\"" } @attrs )
                    . ">";
            }
            $ret .= _html_to_docbook( $node, 1 );

            if ( $node->nodeName() eq "a" )
            {
                $ret .= "</ulink>";
            }
            else
            {
                $ret .= "</" . $node->nodeName() . ">";
            }
        }
        else
        {
            $ret .= $node->toString();
        }
    }

    # Remove leading and trailing space.
    if (1)
    {
        $ret =~ s!^\s+!!mg;
        $ret =~ s/\s+$//mg;
    }
    return $ret;
}

sub _render_s_elem
{
    my ( $self, $s_elem ) = @_;
    return _html_to_docbook($s_elem);
}

sub _render_sys_table_row
{
    my ( $self, %args ) = @_;

    $self->_out( "<row>\n<entry>"
            . $args{name}
            . "</entry>\n"
            . "<entry>\n"
            . $args{desc}
            . "\n</entry>\n</row>\n" );
}

sub _render_sys_table_end
{
    my $self = shift;
    $self->_out("</tbody>\n</tgroup>\n</table>\n");
}

sub _render_section_end
{
    my ( $self, %args ) = @_;

    my $depth = $args{depth};

    if ($depth)
    {
        $self->_out("</section>\n");
    }
}


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

XML::CompareML::DocBook - convert CompareML to DocBook

=head1 VERSION

version 0.2.13

=head1 SYNOPSIS

See L<XML::CompareXML>.

=head1 AUTHOR

Shlomi Fish, L<http://www.shlomifish.org/>.

=head1 SEE ALSO

L<XML::CompareML>

=head1 COPYRIGHT AND LICENSE

Copyright 2004, Shlomi Fish. All rights reserved.

You can use, modify and distribute this module under the terms of the MIT X11
license. ( L<http://www.opensource.org/licenses/mit-license.php> ).

=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan

=head1 SUPPORT

=head2 Websites

The following websites have more information about this module, and may be of help to you. As always,
in addition to those websites please use your favorite search engine to discover more resources.

=over 4

=item *

MetaCPAN

A modern, open-source CPAN search engine, useful to view POD in HTML format.

L<https://metacpan.org/release/XML-CompareML>

=item *

RT: CPAN's Bug Tracker

The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.

L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-CompareML>

=item *

CPANTS

The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.

L<http://cpants.cpanauthors.org/dist/XML-CompareML>

=item *

CPAN Testers

The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.

L<http://www.cpantesters.org/distro/X/XML-CompareML>

=item *

CPAN Testers Matrix

The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.

L<http://matrix.cpantesters.org/?dist=XML-CompareML>

=item *

CPAN Testers Dependencies

The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.

L<http://deps.cpantesters.org/?module=XML::CompareML>

=back

=head2 Bugs / Feature Requests

Please report any bugs or feature requests by email to C<bug-xml-compareml at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=XML-CompareML>. You will be automatically notified of any
progress on the request by the system.

=head2 Source Code

The code is open to the world, and available for you to hack on. Please feel free to browse it and play
with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
from your repository :)

L<https://github.com/shlomif/xml-compareml>

  git clone git://github.com/shlomif/xml-compareml.git

=head1 AUTHOR

Shlomi Fish <shlomif@cpan.org>

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website
L<https://github.com/shlomif/xml-compareml/issues>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Shlomi Fish.

This is free software, licensed under:

  The MIT (X11) License

=cut
